package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(D@`````````0```````
M`+&8``````!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*8`````````I@``
M```````0``````$````&````````J]````````"[T````````+O0````````
M!+@````````$X````````!```````@````8```````"KX````````+O@````
M````N^`````````"``````````(```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````GO````````">\````````)[P`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O0````````N]``````
M``"[T`````````0P````````!#```````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`L+_)A#D]_METPQRS36%=T0["[?@````$````$```
M``%'3E4```````````,````"```````````````1````0@````0````(A`1`
M!0`0$""$`(:`!``"*`@$(`D"`(F""`(`ND$0@(@`````````0@```$4```!(
M````20```%$```!2````4P````````!5````5@```%<```!8````60```%L`
M`````````!_?Q6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C
M2ZR'U_I"+#_EPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,
M%0N7.@V;G*E_"@*GX%">&FM)^^"C````````````````````````````````
M```````````#```+````````&,```````````````V$2````````````````
M`````````````.02`````````````````````````````JT1````````````
M`````````````````GT2`````````````````````````````)82````````
M`````````````````````5T2`````````````````````````````;42````
M`````````````````````````/H2``````````````````````````````$@
M`````````````````````````````702````````````````````````````
M`K42`````````````````````````````9P2````````````````````````
M`````>,2`````````````````````````````2L2````````````````````
M`````````=P2`````````````````````````````1L2````````````````
M`````````````0T2`````````````````````````````=02````````````
M`````````````````J,2`````````````````````````````!`@````````
M`````````````````````7L2`````````````````````````````@H2````
M`````````````````````````JL1`````````````````````````````E@2
M`````````````````````````````"P@````````````````````````````
M`C@2`````````````````````````````$82````````````````````````
M`````A,2`````````````````````````````&,6````````````````````
M`````````4T2`````````````````````````````:X2````````````````
M`````````````'82`````````````````````````````-,2````````````
M`````````````````(<2`````````````````````````````:02````````
M`````````````````````E\B`````````````````````````````I(2````
M`````````````````````````9<2`````````````````````````````+<2
M`````````````````````````````>X2````````````````````````````
M`@,2`````````````````````````````?02````````````````````````
M`````3\2`````````````````````````````.X2````````````````````
M`````````882`````````````````````````````FX2````````````````
M`````````````BD2`````````````````````````````C<2````````````
M`````````````````<T2`````````````````````````````*(2````````
M`````````````````````>D2`````````````````````````````6@2````
M`````````````````````````.D2`````````````````````````````;X2
M`````````````````````````````,81````````````````````````````
M`<42`````````````````````````````H02````````````````````````
M`````AL2`````````````````````````````302````````````````````
M`````````G42`````````````````````````````%02````````````````
M`````````````C\2`````````````````````````````HL2````````````
M`````````````````E$1`````````````````````````````VH2```-````
M````0>@`````````U@```[\2```-````````.0@````````&F````DP2```-
M````````'\`````````"B````N$2```-````````*S``````````!@```O\2
M```-````````/Z`````````"1````^42```-````````*S@````````"7```
M`Z40```7````````P(@``````````````O(2```-````````+9@`````````
M-@```Q42```-````````-/@`````````>````W81```/````````7F``````
M````!````Y(2```-````````6>@````````!R@```YT2```-````````*B``
M````````.````[H0```7````````P+```````````````],2```-````````
M.!@`````````Z@```_P2```-````````-7``````````>````X40```6````
M````P````````````````SD2```-````````+=`````````!2````\P0```7
M````````P(@``````````````_(1```6````````P(``````````"````XL2
M```-````````(D@``````````````[$2```-````````67@`````````;```
M`X<@```6````````P````````````````T\2```-````````-^@`````````
M+@```R,2```-````````*E@`````````U````T42```-````````6[@`````
M```":```!`02```-````````+Q@````````%W`!?7V=M;VY?<W1A<G1?7P!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E
M;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E
M861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK
M`&UE;6UO=F4`<W1R=&]K`')M9&ER`')E860`;6MD:7(`7U]V9G!R:6YT9E]C
M:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P
M<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE
M;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;W!E;F1I<@!G971U:60`86-C
M97-S`&UE;6-P>0!?7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`
M<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A
M<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA
M7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,S0`
M1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR````
M``````(``0`"``(``0`!``(``0`!``(``P`"``(``0`"``$``0`"``(``0`!
M``(``@`"``$`!``!``(``0`!``(``0`!``$``@`"``(``@`!``(``@`%``$`
M`0`%``(`!0`$``(``0`"``$``@`"``$``@`"``4``0`"``$`!@`"``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$`!0```M<````0``````:6D;0````&```$$0```!`-:6D4````!0``
M!!P````0!I:1LP````0```0F````$`EI&7(````#```$,0```!`-:6D2````
M`@``!#T`````````````N]``````````#````````",X````````N]@`````
M````#````````"+P````````O_@`````````#````````!_`````````P`@`
M````````#````````,`(````````P"``````````#````````&%@````````
MP"@`````````#````````%Z\````````P#@`````````#````````%]<````
M````P$``````````#````````%]@````````P$@`````````#````````&%4
M````````P%``````````#````````%["````````P%@`````````#```````
M`&%<````````P&@`````````#````````&%$````````P'``````````#```
M`````&%*````````P(``````````#````````&%F````````OZ`````$````
M"@``````````````````OZ@````)````"@``````````````````O[`````*
M````"@``````````````````O[@````5````"@``````````````````O\``
M```:````"@``````````````````O\@````>````.```````````````````
MO]`````?````"@``````````````````O]@````A````"@``````````````
M````O^`````E````"@``````````````````O^@````X````"@``````````
M````````O_````!!````"@``````````````````O?@````"````"P``````
M````````````O@`````#````"P``````````````````O@@````%````"P``
M````````````````OA`````&````"P``````````````````OA@````'````
M"P``````````````````OB`````(````"P``````````````````OB@````+
M````"P``````````````````OC`````,````"P``````````````````OC@`
M```-````"P``````````````````OD`````.````"P``````````````````
MOD@````/````"P``````````````````OE`````0````"P``````````````
M````OE@````1````"P``````````````````OF`````2````"P``````````
M````````OF@````3````"P``````````````````OG`````4````"P``````
M````````````OG@````6````"P``````````````````OH`````7````"P``
M````````````````OH@````9````"P``````````````````OI`````;````
M"P``````````````````OI@````<````"P``````````````````OJ`````=
M````"P``````````````````OJ@````@````"P``````````````````OK``
M```B````"P``````````````````OK@````C````"P``````````````````
MOL`````D````"P``````````````````OL@````E````"P``````````````
M````OM`````F````"P``````````````````OM@````G````"P``````````
M````````ON`````H````"P``````````````````ON@````I````"P``````
M````````````OO`````J````"P``````````````````OO@````K````"P``
M````````````````OP`````L````"P``````````````````OP@````M````
M"P``````````````````OQ`````N````"P``````````````````OQ@````O
M````"P``````````````````OR`````P````"P``````````````````OR@`
M```Q````"P``````````````````OS`````R````"P``````````````````
MOS@````S````"P``````````````````OT`````T````"P``````````````
M````OT@````U````"P``````````````````OU`````V````"P``````````
M````````OU@````W````"P``````````````````OV`````Y````"P``````
M````````````OV@````Z````"P``````````````````OW`````[````"P``
M````````````````OW@````\````"P``````````````````OX`````]````
M"P``````````````````OX@````^````"P``````````````````OY`````_
M````"P``````````````````OY@```!`````"P``````````ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```4H;`$```4VOC$!````2Y`@`1IX0``PWAXT#Q$``$
MZV_PT``$!_0'!^,0\#@`),`0``!2;=('\#`0".,0$!``!`?Q!P`'``<`P!``
M`%)LXQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4F#C$!````0'\0T0
MXQ`0#``4P/3____5````&,`0``!25.,0$```!`?Q#1#C$!`,`!3`]/___\4`
M```PP!```%)(XQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```4CSC$!``
M``0'\0T0XQ`0#``4P/3___^E````8,`0``!2,.,0$```!`?Q#1#C$!`,`!3`
M]/___Y4```!XP!```%(DXQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```
M4ACC$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!2#.,0$```!`?Q#1#C
M$!`,`!3`]/___V4```#`P!```%(`XQ`0```$!_$-$.,0$`P`%,#T____50``
M`-C`$```4?3C$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!1Z.,0$```
M!`?Q#1#C$!`,`!3`]/___S4```$(P!```%'<XQ`0```$!_$-$.,0$`P`%,#T
M____)0```2#`$```4=#C$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!1
MQ.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%&XXQ`0```$!_$-$.,0
M$`P`%,#T___^]0```6C`$```4:SC$!````0'\0T0XQ`0#``4P/3___[E```!
M@,`0``!1H.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```%&4XQ`0```$
M!_$-$.,0$`P`%,#T___^Q0```;#`$```48CC$!````0'\0T0XQ`0#``4P/3_
M__ZU```!R,`0``!1?.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```%%P
MXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```463C$!````0'\0T0XQ`0
M#``4P/3___Z%```"$,`0``!16.,0$```!`?Q#1#C$!`,`!3`]/___G4```(H
MP!```%%,XQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```44#C$!````0'
M\0T0XQ`0#``4P/3___Y5```"6,`0``!1-.,0$```!`?Q#1#C$!`,`!3`]/__
M_D4```)PP!```%$HXQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```41SC
M$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!1$.,0$```!`?Q#1#C$!`,
M`!3`]/___A4```*XP!```%$$XQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`
M$```4/CC$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0[.,0$```!`?Q
M#1#C$!`,`!3`]/___>4```,`P!```%#@XQ`0```$!_$-$.,0$`P`%,#T___]
MU0```QC`$```4-3C$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!0R.,0
M$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```%"\XQ`0```$!_$-$.,0$`P`
M%,#T___]I0```V#`$```4+#C$!````0'\0T0XQ`0#``4P/3___V5```#>,`0
M``!0I.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%"8XQ`0```$!_$-
M$.,0$`P`%,#T___]=0```ZC`$```4(SC$!````0'\0T0XQ`0#``4P/3___UE
M```#P,`0``!0@.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```%!TXQ`0
M```$!_$-$.,0$`P`%,#T___]10```_#`$```4&CC$!````0'\0T0XQ`0#``4
MP/3___TU```$",`0``!07.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!``
M`%!0XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```4$3C$!````0'\0T0
MXQ`0#``4P/3___T%```$4,`0``!0..,0$```!`?Q#1#C$!`,`!3`]/___/4`
M``1HP!```%`LXQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```4"#C$!``
M``0'\0T0XQ`0#``4P/3___S5```$F,`0``!0%.,0$```!`?Q#1#C$!`,`!3`
M]/___,4```2PP!```%`(XQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```
M3_SC$!````0'\0T0XQ`0#``4P/3___RE```$X.MO\#``)./P_SC_<>,P\*@`
M).-`\*``)%`@\+1!0/"@03#PJ$$@\+2R3P"PZ[L`(``-LD\`L=('\,"P*,#E
M____LL1(``!/T\0H``!/Z+D$`#3`Y0``'P?$&```3^B5`!``IX0`N,`P``!/
MT>-0,```!%B@\+3LF@`$`-BY%`#IXV6P```$ZRX``P`-E@-DBJ>J``/`Y?__
M_P;C$/"H``3`,```(&[C`!````3C,"`(`"3C`"```"2Y!`!2Q"L``%`.P$``
M`"!?XT!0&``DQ"@``$_YXR!0$``D6)#PM*>>``&GQ`#'[.D``P#8[`G__P#8
M03`0"*<H``2G`0`!IW0`A(@```&Y%`!"[!(``0#8Z^0``P`-N10`8>-`,```
M!.-.4```).L6``,`#>-@,`@`!.-A4```)*<J``*G.P`0IP;_X^QI``,`V+D4
M`);K.0`#``VY%`!*IVD``$&C4`#$*```3\3E2*````#`,```!#[`Y?___#<2
M(J>$`%7$*```3[5!8/"\P.7___W\N00`-KD$`)+`(```'MS`Y0```/*Y`@`B
MIX0`1\0H``!/G\#E___[Z,#E___]%=4'\,"P**=T`%NY!``IZV_P^``$!_[`
MY?___,?$*P``3XBY`@`BIX0`3L#E___]/<`P``!/#N,@,```!.-"L```!)(`
M27ZG]/\UXS`P```$XS!0(``DIR@`!4$P$!`9+J=T_W.G]/^2Q"@``$]BP.7_
M__P[I_3_I\!0``!/5N,@4````J>$``?`Y0``#_*G]/^PN00`-L`@```>5L#E
M````E,0K``!/0;D"`"*GA/^AI_3_[*=H``2G]/]KP.7___VDIRD``<#E___]
M+T%`\`CC,/````2G"?_PN8``\*?[_U#7!_``\`#K[_"@`"1!</"@IVD``*=9
M``#`(```3L'C("````3`Y?___G\```<'!P<'!\`0``!._,`@``!.^;D@`!('
MCL08``!.B[D"`!$'C@?QP!```$[LP"```$[IN0D`$NL!``,`"NLQ`#\`#+D(
M`##K,P`!``JY`@`S!X[$&```3G*Y`@`1!X[`(```3M`'\>N_\%@`),"P``!.
MR>/P_V#_<94`L`"G=``5P!```$YKXQ`0```"IX0`",0H``!.=\#E___\H,#E
M____M9(!L`#KO_#X``0'_L#T____O`<'ZV_P,``DX_#_8/]QN0(`@J>$`%K$
M&```3B;C<!````*GA`!2N00`8^,`@```E+D$`)B5`(``IX0`3Z<.`#VGA``+
M09"0`>,`D```E)4`D`"G=/_U&YCCH'````*GA``?N10`F;D$`+>Y!`!)N00`
M.+D$`"K`Y?__^Z82(J=T``A!*:``E3T@`*>$``]!L+`(XZ"P```"IW3_Z;D$
M`"KK;_#0``0'_D&IH`&YZ7`[N00`*NM#``,`"E!`8`#K;_#0``0'_J>I``"Y
M!``JZV_PT``$!_ZGF```I_3_OP<'!P?KK_!0`"3C\/[(_W&R3P"PN00`HNN[
M`"``#4$P\*"R3P"QT@?Q,+`HP.7___S,$B*G=``?&!)8(/"XP"L``/``IRY`
M`*>$``?"+0``H`"G=``2N00`*J<Y``+`Y?___3,0$J<:__^($``?I_0`!*<8
M``"Y%``AU0?Q,+`HIW0`!NNO\8@`!`?^P.7___QL!P?K;_`P`"3C\/[`_W&R
M3P"@ZZH`(``-LD\`H;D"`&+2!_$XH"BGA``&E0!@`*=T``O5!_$XH"BG=`"3
MZV_Q<``$!_[`Y?___2>Y`@"2IX3_\KD$`"G`Y?__^YZY`@`BIX0`9$&P(!.5
M+B`3IW0`!I4`L`&GA/_OE2X@$Z>$`&*G"```N00`%KD$`#NG20``IUD``+)>
M`$&G%/_^LEX`4Z<4__ZY"0!&N0D`6QI%ITH``KD4`"3`Y?__^C[CL/"@`"3`
M4```''JY!`"RITG__Z<Y``'`Y?___+]!,/"HN00`*\#E___Z^*<N__^Y!``K
MIX0`"U@`\,#`"P``\`"G#D``IX0`*<#E___\)KD$`"O`Y?___&&Y!``IP.7_
M__L\N0(`(J=T_Z"Y!``IP.7___GSN00`)L#E___Z+J?T_WN5+K`!IW3_GI4`
ML`*GA/^#I_3_F,#E____5Z?T_]G`Y?__^[H'!P<'!P?K;_`P`"3C\/](_W&R
M3P!@ZV8`(``-LD\`8;D$`+*Y!`"CT@?PL&`HE3TP`*=T``1!H#`!IP@``+D$
M`!JGB0``LEX`@:<4__ZY"0"*03#PK+D$`"O`Y?___FJY`@`BIX0`G:<(``"G
MV0``N00`$K)>`-&G%/_^N0D`TKDA`(VGQ`!ZXW#PK``4Q-@``$R`ZW<``P`-
MXR"P``"4N00`2Y4`L`"G=``-I_0`[D%`0`'C($```)25`$``IX0`!J<N`#VG
M=/_UN0D`2[D4`)1!*)`"N00`A^.`T```",#E___Y=^,@@```)+D"`"*GA``[
MXP"P``"0XS#0```$XU<P```$0@!0`$'@L`$8<+D"``"G=``0I_0`/^,0X```
MD$(0L`%!X.`!&'&Y`@`1IX0`,T)P\*"Y!`"UE3WPH$%04`&G=/_LDCVP`*?9
M``#C3:```)!"3;`!I]L``;D"`$2G=/_WU0?PL&`HIW0`F.MO\.@`!`?^IYD`
M`..)H```D$*)(`"GFP`!N0(`B*=T__>G]/_JN00`M:?T_]?$V```2_CC<-``
M``3C$'````*GA`!PN00`1Z>8```8":>:``%!0$`(XS!````"IW3_^*<*``.Y
M%``PZR,``P`-P%```$Q0XQ!0```2IW0`-\#@``!,2.5,X````<#E___XZKD"
M`!+C$/"@`"2GA/^NN00`-[D4`'GK=P`#``VY!`!'P.7___E7XR#PH``$XR#0
M```D4)#PK.-0\*``!*>:``&Y%`"9ZSD``P`-0>-0`.5(X````*?T_R.Y!``R
MN00`)\#E___YI^,@\*``).,@T```)+D"`"*GA/]XN10`2>MT``,`#:?T_]>G
MF0``I_3_(Z<I`!"GF```I_3_H\#E___Z:0<'!P?K?_`X`"3C\/]8_G'C$/"@
M`7&Y!`"BN00`D[)/`+!!@/"@Z[L`(``-N00`.+)/`+&G20__P"```!J_T@<0
M`+`HP.7___DD$B*GQ``1[`+__P#8&!*Y%``@03+PH)4`,`"G=``B$@"G=``>
MP%```$M3X^!0```$N00`2;D$`#KC+K````3`Y?__^,+C0/"@`7'5!T``L"BG
M=``JZW_PX`$$!_X8$+D4`'&G.0`ON00`1[D$`"C`Y?__^/JY`@`BIX3_UKD$
M`#JY!`!7P*```$LCN00`2..0H```!.,IL```!,#E___YE*?T_]+`Y?__^>_`
M$```2Q#`4```.I7$2```2P[K;_`P`"3`,```&EWCL!````3C\/]8_W&R3P"@
MZZH`(``-LD\`H>,KH```!,!@```;JL#E___ZFKD$`%;E2/"@``#`0```"M+C
M*Z````3`,```&D?`Y?__^/GK;_#8``0'_@<'!P>R3P`@P!```$K2ZS(`(``-
MXT`0```$LD\`,<!0```Z3^,D,```!,1(``!*Q<`P```:%\#T___Z9^MO\#``
M)./P_TC]<>,0\+`"<;)/`)#KF0`@``VR3P"1T@<0`)`H0;#PKN.`\*\!<<#E
M___Y/,`````:%>,`\*``)+D$`&+`4```&@>G21`!ISD``;D$`"O`Y?__^BBG
M21``N00`*[D$`#C`Y?__^#\2(J=$`"JY!`!BIRH``;D4`"+`Y?__]X.Y`@"B
MIX0`#[D4`+:Y!``XN00`2\#E___Z5D$[H`"2`#``XT#PL`)QU0=``)`HIW0`
M#+D$`"KK;_#H`@0'_J>I``"G]/_PP.7___DM!P<'!\#T____E`<'ZV_P,``D
MX_#^L/YQXQ#Q2`%QN00`LKD$`).R3P!P03#PM.MW`"``#<`@```9K[)/`''2
M!Q``<"C`Y?__^^BG.0`ON00`HKD$`"O`Y?__^0^Y`@`BIX0`&,`@```9G+D$
M`#O`Y?___3^Y!``KXQ#Q2`%QU0<0`'`HIW0`[^MO\8`!!`?^N00`*<#E___X
M$,`P```9B,#E___W6KD"`&*GA/_=09#Q2$&`\+B5`&``IX0`IKD"`*JGA``.
MIP@``+D$`#:Y!``JLET`,J<4__ZGA`"&IP@``*=)``"Y!`!6LEX`1:<4__ZY
MZ6`DXQ!/__]QN2$`8:>D`#>YZ6`!IP$``:>$``^5+Q``IW0`(9(`$`#C$!__
M_W&Y(`!AIX0`&.O@``$`#)4O$`"G=``1D@`0`.LO'___5:=T``KK`!___U+C
M$!_^_W&GY__OIP@``*<I``"Y!``VLEX`(Z<4__ZY"0`FIP@``*=)``"Y!`!;
MLEX`1:<4__ZY"0!+000@`<(.```/_Z<D_VK`X```&0SCL/"H`"3CX/"@`"3`
M4```&7JG21``ISD``;D$`"G`Y?__^0ZY!``XN00`*<#E___W1Q(BIW0`#%A@
M\-#`:P``\`#";0``@`"GA``GP#```!CBIRD``,#E___VLKD"`&*GA/\UE0!@
M`*=T_UZY`@"JIX0`!I4NH`"GA``)IRD``<!@```8NZ?T_Z>5`*`!IX3_WZ?T
M__6G.0`!N00`*<#E___XOA(BIW3_T[D$`#G`(```&*K`Y?___$^Y!``IP.7_
M__<NI_3_#<#E___W^0<'!P?KO_!8`"2G.0`OX_#_8/]QN00`LL#E___XBKD"
M`"*GA``$0;`@`;D$`"OKO_#X``3`]/__]PP'!^N?\$@`)./P_UC^<;)/`*#C
M$/"@`7'KJ@`@``VR3P"AT@<0`*`HN0(`,J>$`&25`#``IX0`8*<(``"GF0``
MN00`([)>`)*G%/_^N0D`D^Q)``$`V<).```0`*<D`'!!L/"@N00`*\#E___X
MM>-)O___<;DA`$NGQ``>N>FP!*=!``&G=`!)ZS```0`,E2]``*=T`!&2`$``
MZR]/__]5IW0`"NL`3___4N-`3_[_<:<W_^^G.0`ON00`*\#E___X&[D"`%*G
MA``7N2$`6Z<D`#.Y!``KP.7___:>X^#PH`%QU0?@`*`HIW0`+NN?\/`!!`?^
MXQ#PH`%QU0<0`*`HIW0`(L`@```7]>N?\/`!!,#T___V@94O0`"G=/_-D@!`
M`.-`3___<;D@`$NG=/^NI_3_PI(`4`"G]/_-IRD``*?T_\[`Y?__]S?KK_!0
M`"3C\/]0_W&R3P"@0;#PI.NJ`"``#;)/`*'2!_"HH"BY!``[P"```!?-P.7_
M__G]N0(`(J>$`##C0/"D`!3$*```2"/K%``#``WC$"````CC4!`(``3C4!``
M`"2Y`@!5IX3_X.,`$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$`#O`(```%Y_`
MY?__^<^Y`@`BIW3_U+D$`#O`(```%YC`Y?__^<.Y`@`BIX0`,.,0\*0`%,18
M``!'Z>OA``,`#>/@4```".,`X`@`!.,`X```)+D"``"GA/_@XS#@$``$XS#@
M"``D0>#@"+D"`#.G=/_VN00`.\`@```7:L#E___YE;D"`"*G=/_4N00`.\`@
M```78L#E___YB;D"`"*GA``PXU#PI``4Q.@``$>OZT4``P`-XT#@```(XS!`
M"``$XS!````DN0(`,Z>$_^#C($`0``3C($`(`"1!0$`(N0(`(J=T__:Y!``[
MP"```!<TP.7___E;N0(`(J=T_]2Y!``[P"```!<MP.7___E/N0(`(J>$`##C
M,/"D`!3$*```1W7K$P`#``WC$"````CC0!`(``3C0!```"2Y`@!$IX3_X.,`
M$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$`#O`(```%O_`Y?__^2&Y`@`BIW3_
MU+D$`#O`(```%O?`Y?__^16Y`@`BIX0`,.,0\*0`%,1(``!'.^M1``,`#>-0
M0```".,`4`@`!.,`4```)+D"``"GA/_@X^!0$``$X^!0"``D05!0"+D"`.ZG
M=/_VN00`.\`@```6R<#E___XY[D"`"*G=/_4N00`.\`@```6Q<#E___XV[D"
M`"*GA``PXT#PI``4Q%@``$<!ZS0``P`-XS!0```(X^`P"``$X^`P```DN0(`
M[J>$_^#C(#`0``3C(#`(`"1!,#`(N0(`(J=T__:Y!``[P"```!:7P.7___BM
MN0(`(J=T_]2Y!``[P"```!9CP.7___BAN0(`(J>$`##CX/"D`!3$*```1L?K
M'@`#``WC$"````CC,!`(``3C,!```"2Y`@`SIX3_X.,`$!``!.,`$`@`)$$0
M$`BY`@``IW3_]KD$`#O`(```%C7`Y?__^'.Y`@`BIW3_U+D$`#O`(```%E?`
MY?__^&>Y`@`BIX0`,.,0\*0`%,0X``!&C>M!``,`#>-`,```".,`0`@`!.,`
M0```)+D"``"GA/_@XU!`$``$XU!`"``D04!`"+D"`%6G=/_VN00`.\`@```6
M*<#E___X.;D"`"*G=/_4N00`.\`@```6(L#E___X+;D"`"*GA``PXS#PI``4
MQ$@``$93Z^,``P`-X^!````(XU#@"``$XU#@```DN0(`5:>$_^#C(.`0``3C
M(.`(`"1!X.`(N0(`(J=T__:Y!``[P"```!7TP.7___?_N0(`(J=T_]2Y!``[
MP"```!7MP.7___?SN0(`(J>$`##C4/"D`!3$Z```1AGK%0`#``WC$.````CC
M(!`(``3C(!```"2Y`@`BIX3_X.,`$!``!.,`$`@`)$$0$`BY`@``IW3_]KD$
M`#O`(```%;_`Y?__]\6Y`@`BIW3_U+D$`#O`(```%8#`Y?__][FY`@`BIX0`
M,.,0\*0`%,0H``!%W^LQ``,`#>,P(```".,`,`@`!.,`,```)+D"``"GA/_@
MXT`P$``$XT`P"``D03`P"+D"`$2G=/_VN00`.\`@```54L#E___WB[D"`"*G
M=/_4N00`.\`@```5?L#E___W?[D"`#*GA``(P"```!5JP.7___CAN00`.\`@
M```5=<#E___W;;D"`#*GA``(P"```!5TP.7___C/N00`.\`@```5<L#E___W
M6[D"`#*GA``9P"```!43P.7___B]U0?PJ*`HIW0`(L`P```5;L`@```5)>NO
M\0``!,#T___XK+D$`#O`(```%5?`Y?__]SBY`@`RIX3_Y<`@```5'L#E___X
MFJ?T_]W`Y?__]$D'!P<'Z[_P6``DP"```!4.X_#_4/]QLD\`L$$P\*3KNP`@
M``VR3P"QT@?PJ+`HP.7___</N0(`(J>$`!N_`2``IX0`%\`'````,+F$`!"Y
M`P`Q[$,_OP%5N10`)-4'\*BP**=T``KKO_$(``0'_J=(``"G]/_SP.7___0+
M8`#P@&`@\(A@0/"08&#PF+)/`!#K/_`8`"3C\/\X_W'K,0`@``VY!`!"LD\`
M,4$`\6A!(/#(Q&@``$4E05#PH-('\,`P*.,@\+@`).,`\+``).5(\*```>5(
M\*@``.,@8```!*<Y``'`Y?__\Z2G*0#_P.7___-?ITD``J<Y``#KC_!``"3C
M\/]0[W'C$/"H$'&Y!`""LD\`H.NJ`"``#;)/`*'2!Q``H"C`Y?__\@/LDO__
M`-GL"3"``%6Y`@``IZ0`"Z<+___`(?__``"Y@0`"IPL``;D)`)!!L/"@N0(`
MF:=$`*BG20``N00`.;D$`"C`Y?__\=^G+___IX0`M<!!``$`"+D$`#NY!``H
MP.7___/AIR[__Z>$`*&Y%``RPCX````'I\0`?N,3O_C_<;DA`!NG1`!W[$$^
MOP!5P%```$2QU0=0`!``IX0`@N,0'___<;DA`!NG1`!EN0(`1*>$`"^G3P`!
MIX0`'*=/``*GA``-P.```$26U0?@`!``IX0`9^,0'___<<`@``!$B]4'(``0
M`*>$`%SC$!___W'`,```1(#5!S``$`"GA`!1XQ`?__]QN2$`&Z=$`#3`0```
M1''5!T``$`"GA`!"XU`?__]QP.```$1FN00`%=4'X`!0`*>$`#7C$%___W'`
M(```1%G5!R``$`"GA``JQ`@``$11XQ!?_O]QXP!?_O\@IX0`'^,07_W_<;DA
M`!NGI/_0PI0``0``PIS__P``IW3_7*<I___C@/"H$''5!X``H"BG=``8ZX_P
M\!`$!_ZYZ;`AN0@`*:?T__#`(```$^C`Y?___M#`(```$]O`Y?___LK`Y?__
M\L_K[_!P`"3C\/]@_W'`Y?__\+;`Y?__\).Y`@`BIX0`!>,@(```!.OO\1``
M!`?^!P?K;_`P`"3C\/]`_W&R3P"@N00`8NNJ`"``#4$P\+2R3P"AP"```!.V
MT@?PN*`HP.7___5]N0(`LJ>$``:5`+``IW0`$M4'\+B@**=T`$VY!``VP"``
M`!.>ZV_P\``$P/3___;1IP@``+D$`#NY!``6ITD``*<I``"R7@!#IQ3__K)>
M`"&G%/_^N0D`2[D)`"9!(D`"P.7___":P````!,2X[#PJ``DXP#PH``DN00`
MLL!0```3?Z=)__^G.0`!P.7___,5U0?PN*`HIW0`#;D$`#O`(```$U[K;_#P
M``3`]/__]I'`Y?__\D('!P<'!P?K;_`P`"3C\/X0_W&R3P!PZW<`(``-LD\`
M<<`0``!#=[D$`-)!H/#$P"```!+'N00`.M('\>AP*-(/\,@0$-('\-@0(-(O
M\/@0*-(/\.`06-('\/`0:,#E___T\;D"`+*GA``&E0"P`*=T`FK`Y?__[_;`
MY?__[].Y`@`BIX0!%^.P(````J>$`1*G"```ISD``+D$`$NR7@`TIQ3__KD)
M`#OK(P`!``VG*P`!P.7___`6E0"P`.-@L```E+D$`)*Y!`""IX0`&[F$`&:Y
M!``IP%```!+SITG__Z<Y``'`Y?__\HU!L+`!09"0`N-@L```E)4`L`"G=/_I
M09#Q`,`@```2JZ?T``FGFP`(XR"?^/\"IX0`'KD$`#K`Y?__](^Y`@"RIX3_
M\I4`L`"GA/_NP.7___3T$B*GA/_HN00`*\#E___PS+D"`&*G=``<09#PR.-@
MD````J>$`!65`&``IX0`H;D$`";`Y?__]-@2(J=T`(RGFP`(XV"0```"IW3_
M[Z<(``"Y!`!8N00`)J<Y``"G20``LEX`,J<4__ZR7@!%IQ3__KD)`#:Y"0!(
M&C2G.@0$N10`L[D$`"O`Y?__[X[`````$H+C@/"P`"3C`/"H`"2Y!`"2P%``
M`!)RITG__Z<Y``'`@```$?7C@/"@`"3`Y?__\@.G.0'`N00`*<#E___P[*<N
M__^G=``+P.7___"U6&`@`*=N`!&G=`%V03#Q*+D$`"G`Y?__\5@8@A(BIW0`
M"UC@\4#`ZP``\`"G[D``IX0`>,2H``!"4+D$`&GC4-````3`0```$ECC(*``
M``2G.0`!P.7___$HI[D``-4'\>AP**=T`@>Y!``KZV_R(``$!_ZGFP`(N00`
M)L#E___P)+D"`&*GA/]<I_3_<J=I``"G]/]N08#PX.,@@````J>$`!:Y!``Z
MP.7___.^N0(`4J>$``:5`%``IW0`&:>+``CC((````*G=/_NIRD`#<"P```1
MY<#E___N]Z=H`%.Y!`"2N00`@J?T_N;`Y?__[^RY`@"RIX3_Y*<(``"GZ0``
MN00`&[)>`.&G%/_^N0D`Z^LN``$`#:<K``&G]/Z^6&#Q1,#E___ND!EBIW3_
MA%@0\4#`&P```?^G'@'`IW3_>[D$`"O`Y?__[K^Y!``ZN00`LL`@```1^L#E
M___S9;D"`#*GA`#RXR#0```$P.7___=7N0(`8J>$`.BG"```ITD``+D$`#:R
M7@!#IQ3__KD)`$:G3@`#I\0`'KD4`"3`4```$=?CXF_\_W&R70!>IQ3__J=T
M`!"G3@`$IX0!-Z=*__NY%``404%@`)4O0`"GA`$MN00`.L`@```1$\#E___S
M([D"`**GA`"UXP"@``"4$@"GA`"OIPX`,*>$`*O`,```$3?`(```$/S`Y?__
M]'BY!`!IP.7__^_GP$```!(!P#```!#-XT#PL``DXS#PH``DXR#PJ``DP%``
M`!&>N00`*Z=)__^G.0`!P.7___#,I_0`,L#E___OAU@@(`"G+@`1IW0`-*>*
M``'`H```$*C`Y?__[[G`4```$=.Y%``(XU#PN``DXR#PJ``DXZ#PH``DN00`
M:>,`\+``)+D$`"O`4```$7&G2?__ISD``<#E___PFJ<Y`<"Y!``KP.7__^^#
MIR[__Z>$_\>Y!``IP.7___!*N00`.\`@```09,#E___T#KD$`"O`Y?___0FG
M]/ZWN10`%L0X``!`[N,0\*``)+D$`&GC4-````3`0```$-7C(#````2G.0`!
MP.7__^_#I_3^F\#E___\ZM4'\>AP**=T`)^Y!``KZV_R(``$P/3__^[!XV#0
M```$I_3_%[D$`":G.0``P.7___`5N00`TA(BIX3_3<#E___[L;D"`&*G1/]&
MITD``.,P;_;_<;D$`"W`Y?__[;^G20`&03#QN;D$`"W`Y?__[\:G+P`&IW0`
M:\`0```P$-4%$`#QN:=T_R?C,&_._W&G20``N00`+<#E___MH+D$`"VG20`H
M0=#QO[D$`#W`Y?__[Z6G+P`HIW0`2L#@```1&\!@```/YY(`\>?C8/"@`"3C
MX/"P`"3CT/"H`"2Y!`!IP%```!"LITG__Z<Y``&Y!``KP.7__^_BI_3_4^/0
MT`@``J>$_M*G"```IRD``+D$`#VR7@`CIQ3__KD)`"W"+@````.GQ/[!XU+?
M_/]QP.```!!\LET`Y:<4__ZYXH!MI_3^L\#E___N^<`@```0<<#E___ZZ^M_
M\#@`),"@``!`$>,0H```!./P_U#_<;)/`+!!@/"DZ[L`(``-P"````^<LD\`
ML;D$`#C2!_"HL"CCD;````32`)"QD+#`Y?__\:VY`@`BIX0`!I4Q(`"GA`#4
MP.7___>.XS"@```$XY.P```$N00`*:=9``.G20`!P#```!!,P.7__^U`N0(`
MDJ>$`![C0)`0``3C<*````3C,$````3C)[````3`0```$#?`Y?__[3KC4)`0
M``3C,%````210#`-IW0`MN-PH```!*=9``/C)[````2G20`!P#```!`@P.7_
M_^T0N0(`DJ>$`!JY!``XP"````\;P.7___%4N0(`0J>$`(7C()`0``3C,"``
M``3C)[````3`Y?__[03CH*````2G20`!XWJP```$P#````_WN00`)\#E___L
M5,!````/^KD$`#*Y!``GP.7__^SJXSJP```$D@`PL<`@```.X;D$`#C`Y?__
M\1W$*P``/\JY!`""N0(`(J>$`"ZG.0'`N00`*,#E___MW>P"``$`V,(/````
M`:?$`!:G+@`1IX0`$KD$`%+$N```/ZBY!`!(P"````_4XS"P```$P.7__^YA
MU0?PJ+`HIW0`.NM_\.@`!`?^Q"@``#^1P.7___O&Q"L``#^/N00`@KD"`"*G
M=/_'P"````^BP.7__^Y#E0`@`:>$_S6G]/\JX^"0$``$Q!@``#]SXR#@```$
MXS`0```$P.7___-ZI_3_>N,GL```!,#E___MQJ?T_T;`Y?__[=$'!P<'ZY_P
M2``DX_#_4/]QLD\`H+D$`++KJ@`@``U!,/"DLD\`H<`@```.B-('\*B@*,#E
M___PE;D"`"*GA``4XQ`@``"4$A&GA``.IQX`,*>$``JY`@"[IX0`!I4`L`"G
M=``+U0?PJ*`HIW0`->N?\/@`!`?^N00`*\#E___UN:<Y`"^Y!`"2P.7__^XJ
MN0(`,J>$``1!D#`!N00`*<#E___LKZ=)``3`,```#J'`Y?__[#<2(J=T_]?5
M!_"HH"BG=``*N00`*^N?\/@`!,#T___P_\#E___M9`<'05`@.*<)``3K;_`P
M`"3C\/S0_W&R3P"@01#PJ.NJ`"``#;)/`*'2!_,HH"CC0%````3C,%`(``3K
MM``@``SCL!```"3K8P`@``SC8!`0`"3`2@````#C0!`(`"3`.@````#C,!`8
M`"1!4%`0IQL`(*<'_][C,/$0``3C@/$8``3C$/$@``3CD/"H``3C0/"P``1!
ML/"XIUD`0+D$`''CT+````2Y!`#MX^"P,`""N8(`X[F"`.GL'B"_(57L'B`^
M`5;C$+!P`"2Y!``XN00`E+D$`(>GNP`(IU<*YN,`(`@`!.,`\*``).-0(!``
M!..P(!@`!+GGL)6Y@`"0N8(`F^-`(```!.M@``(`#.PT(+\E5>Q@`"$>5NPT
M(#H%5NSF(+\`5>-P\+``!+GGX-7">EJ">9FY@`#4N0@`>[F"`-7C$/"H``2Y
MZ'"-PAI:@GF9XQ`@(``(N0@`$[D(`!GLD2"_`%7L`3N_)57L"0`Z!5:Y"``(
MZS0``@`,['`@OP!5[#0`(1Y6[-`[OR55[(,@OP!5[-<`.@56N8(`8^,0\+@`
M!+F``&G"&EJ">9FY@@!NN0@`%>,`\,``!+D(`!;""EJ">9FY"``=N0@`#NOI
M``(`#.SI`"$>5KF"`#[LD2"_`%7L83N_)56YY'`3N00`-NPY`#H%5NQN(+\`
M5;F"`!CCT/#(``2Y"``0PMI:@GF9N0@`$[GH@`WK-P`"``SL@3N_)57L-P`A
M'E;L<2"_`%7LAP`Z!5:Y@@#CXQ#PT``$N8``Z<(:6H)YF;F"`.:Y"`#@N>A@
M`;D(`.CL8R"_`%7KB0`"``SLB0`A'E:Y@@`X[)X@OP!5[-X[OR55N>1PX[D$
M`#WL.0`Z!5:Y@@#FXQ#PV``$N0@`X,(:6H)YF;D(`..YZ&`!ZS<``@`,[&@@
MOP!5[#<`(1Y6N8(`@^Q^(+\`5>S>.[\E5;GDD.BY!`"-[(<`.@56N8(`YN,0
M\.``!+D(`.#"&EJ">9FY"`#HN>A@`>N)``(`#.QC(+\`5>R)`"$>5KF"`#CL
MGB"_`%7LWCN_)56YY'#CN00`/>PY`#H%5KF"`.;C$/#H``2Y"`#@PAI:@GF9
MN0@`X[GH8`'K-P`"``SL:""_`%7L-P`A'E:Y@@"#['X@OP!5[-X[OR55N>20
MZ+D$`(WLAP`Z!5:Y@@#FXQ#P\``$N0@`X,(:6H)YF;D(`.BYZ&`!ZXD``@`,
M[&,@OP!5[(D`(1Y6N8(`..R>(+\`5>S>.[\E5;GD<..Y!``][#D`.@56N8(`
MYN,0\/@`!+D(`.#"&EJ">9FY"`#CN>A@`>LW``(`#.QH(+\`5>PW`"$>5KF"
M`(/L?B"_`%7LWCN_)56YY)#HN00`C>R'`#H%5KF"`.;C$/$```2Y"`#@PAI:
M@GF9N0@`Z+GH8`'KB0`"``SL8R"_`%7LB0`A'E:Y@@`X[)X@OP!5[-X[OR55
MN>1PX[D$`#WL.0`Z!5:Y@@#FXQ#Q"``$N0@`X,(:6H)YF;D(`..YZ&`!ZS<`
M`@`,[&@@OP!5[#<`(1Y6N8(`@^Q^(+\`5>S>.[\E5;GDD.BY!`"-[(<`.@56
MN8(`YN,0\1``!+D(`.#"&EJ">9FY"`#HN>A@`>N)``(`#.QC(+\`5>R)`"$>
M5KF"`#CLGB"_`%7LWCN_)56YY'#CN00`/>PY`#H%5KF"`.;C$/$8``2Y"`#@
MPAI:@GF9N0@`X[GH8`'K-P`"``SL:""_`%7L-P`A'E:Y@@"#['X@OP!5[-X[
MOR55N>20Z+D$`(WLAP`Z!5:Y@@#FXQ#Q(``$N0@`X,(:6H)YF;D(`.BYZ&`!
MZXD``@`,[&,@OP!5[(D`(1Y6N8(`..R>(+\`5>S>.[\E5;GD<..Y!``][#D`
M.@56N8(`YN,0\2@`!+D(`.#"&EJ">9FY"`#CN>A@`>LW``(`#.QH(+\`5>PW
M`"$>5KF"`(/L?B"_`%7LWCN_)56YY)#HN00`C>R'`#H%5KF"`.;C$/$P``2Y
M"`#@PAI:@GF9N0@`Z+GH8`'KB0`"``SL8R"_`%7LB0`A'E:Y@@`X[)X@OP!5
M[-X[OR55XQ#Q.``$N>1PX\(:6H)YF;D$`#WL.0`Z!5;LV""_`%6Y@@#FN0@`
MX+GH8`&Y"`#CZS<``@`,[#<`(1Y6['X[OR55N><P:.Q^(#H%5N.`\4``!,#J
M`````,**6H)YF;GHT!BY@`!IZXX``@`,N8(`;>R.`"$>5KD(`&#K"0`"``RY
M"`!G[`D`(1Y6[',@OP!5N><`T^R6.[\E5;F``-[LEB`Z!5:Y@@#7N0@`T;GG
M@!"Y"`#9N8(`%NSM.[\E5>SM(#H%5N,P\4@`!..0\5``!,(Z;MGKH<*:;MGK
MH;D(`#>Y&@"0N1H`,>QV(K\^5;D(`#[L=@(A'E;LXSN_)56YYW`8[.,@.@56
MN8(`'>QM(K\^5;D:`)'L;0(A'E:Y"`">X^#Q6``$PNINV>NAN1H`Z+GG8(>Y
M@@"#[`D[OR55N1H`Z.P)(#H%5N.`\6``!+D(`.#"BF[9ZZ'L'CN_)56Y&@"'
M[!X@.@56[',BOSY5[',"(1Y6XS#Q:``$N>=PUL(Z;MGKH;F"`-FY&@`VN1H`
MC>QI(K\^5;D(`('L:0(A'E;LF#N_)57LF"`Z!5:YYV`7L\$`:;F"`![CD/%P
M``2Y&@`QPIINV>NAN1H`E[/-`':Y"``W[-,[OR55[-,@.@56['XBOSY5XQ#Q
M>``$['X"(1Y6PAINV>NAN>=PYKD:`!:Y@@#H[&@BOSY5N1H`GNQH`B$>5KD(
M`)VYYV#7[(D[OR55N8(`T^R)(#H%5KD:`!WCX/&```2Y"``8PNINV>NA[(,B
MOSY5N1H`Y^R#`B$>5NP!.[\E5;GG@-;L`2`Z!5:Y@@#9XS#QB``$N1H`[<(Z
M;MGKH;D(`."Y&@`V[&DBOSY5[&D"(1Y6[)X[OR55[)X@.@56N>=@"+/!`'FY
M@@`!XY#QD``$N1H`,,*:;MGKH;D:`)BSS0"'N0@`..S3.[\E5>S3(#H%5NQQ
M(K\^5>QQ`B$>5N,0\9@`!+GG<`;"&F[9ZZ&Y@@`.N1H`%KD:`)#L;B*_/E6Y
M"`"=[&X"(1Y6[.D[OR55N>=@U^SI(#H%5KF"`-/C@/&@``2Y&@`=PHINV>NA
MN0@`'KD:`(?LXR*_/E7L`3N_)57LXP(A'E;L`2`Z!5:YY^#6XS#QJ``$N8(`
MV<(Z;MGKH;D:`(VY&@`VN0@`@.QI(K\^5>QI`B$>5NR8.[\E5>R8(#H%5KGG
M8`ZSP0!IN8(``>.0\;``!+D:`##"FF[9ZZ&Y&@">L\T`YKD(`#[LTSN_)57L
MTR`Z!5;L<2*_/E7L<0(A'E;C$/&X``2YYW`&PAINV>NAN8(`"+D:`!:Y&@"0
M[&@BOSY5N0@`G>QH`B$>5NR).[\E5;GG8-?LB2`Z!5:Y@@#3X^#QP``$N1H`
M'<+J;MGKH;D(`!BY&@#G[(,BOSY5[`$[OR55[(,"(1Y6[`$@.@56N>>`UN,P
M\<@`!+F"`-G".F[9ZZ&Y&@#MN1H`-KD(`.#L:2*_/E7L:0(A'E;LGCN_)57L
MGB`Z!5:YYV`(L\$`>;F"``'CD/'0``2Y&@`PPIINV>NAN1H`F+/-`(>Y"``X
M[-,[OR55[-,@.@56['$BOSY5L\$`#>QQ`B$>5NS>(K\^5;GG<`;LW@(A'E:Y
M@@`.N>?0A^,0\=@`!+F"`(/"&F[9ZZ&Y&@`6L\T`8+D:`)"Y&@`8N0@`ENR#
M(K\^5>SI(+\`5>R#`B$>5NP).[\E5;GG@&WL#@`Z!5:Y@@"6N0@`$.,P\>``
M!,(Z;MGKH;D:`#?L<2"_`%7L$3N_)57L%P`Z!5:Y&@`YXY#QZ``$N0@`,<*:
MCQN\W.L>``(`#+D:`)WL'@`A'E;LT2"_`%6YY-`(L\$`*>SC.[\E5>R3(+\`
M5>-@\?``!+GF$#CLZ0`Z!5:Y@``WPFJ/&[S<N8$`,+/-``*Y"``PN00`!KD(
M`#ZY&@`(Z^<``@`,XV#Q^``$[.<`(1Y6PFJ/&[S<N>30?KF!`!ZYZ-#6N8``
M&;F!`!>Y"``0[(,@OP!5L\$`;>PS.[\E5>PX`#H%5KD(`#'K&0`"``SL&0`A
M'E;LT2"_`%6YY-`.N>80GKF``)BY@0"0L\T`!NQS(+\`5;D(`)#L,SN_)57C
M8/(```3L-P`Z!5;":H\;O-RY!``&N1H`#NOH``(`#.SH`"$>5KGDT(ZY"`"3
MN8$`'NPY(+\`5;F``!?LF3N_)56Y@0`8[),`.@56N0@`$.N'``(`#+D(`!GL
MAP`A'E;C8/((``3L>""_`%7":H\;O-RYY'`.N>C0UNR1.[\E5;/!`#WLT2"_
M`%6YYH`>N8``$[F!`!"SS0`#[)T`.@56N0@`$.-@\A``!,)JCQN\W+D$``:Y
M&@`.Z^,``@`,[.,`(1Y6N>;@.+GD<(ZY"``9N8``/>QA(+\`5>R1.[\E5;F!
M`#CLE@`Z!5:Y"``PN0@`.>R#(+\`5>L=``(`#.P=`"$>5N,`\A@`!+GF$-[L
MDSN_)57""H\;O-SLF``Z!5:SP0!]L\$`*>S1(+\`5;D$`##CD/(@``2Y"``W
MPIJ/&[S<N>30?KD:`)ZSP0!#L\T`XK/-``2SP0!IL\T`-^N6``(`#+F``#;L
ME@`A'E:Y@0`WN>30:;D(`#"Y@0`9N0@`/KF``!BSS0`&N8$`%N/@\B@`!+D(
M`!#"ZH\;O-SL<R"_`%6YZ-#>[#,[OR55[#<`.@56N0@`,>L8``(`#.P8`"$>
M5NSA(+\`5;GDX`GL8R"_`%6SP0`=[(,[OR55N>80.;F``#>Y@0`PL\T``>R&
M`#H%5KD(`##CT/(P``3C`/(X``3"VH\;O-S""H\;O-RY&@#9ZY<``@`,[)<`
M(1Y6N>3@>;F!`!FY@``6N8$`%[D(`!VYZ.#@N0@`..R#(+\`5>PS.[\E5>PX
M`#H%5KD(`#'K%@`"``SL%@`A'E;LT2"_`%6YY-`)[',@OP!5L\$`7NQC.[\E
M5;GF$#FY@``XN8$`,+/-``7L9P`Z!5:Y"``PX^#R0``$XP#R2``$PNJ/&[S<
MP@J/&[S<N1H`Z>N8``(`#.R8`"$>5KGDT(FY@0`9N8``%[F!`!BY"``>N>C0
MT+D(`#;L8R"_`%7L,SN_)57L-@`Z!5:Y"``QZQ<``@`,[!<`(1Y6[($@OP!5
MN>2`">SC(+\`5;/!`"WL<SN_)56YYA`YN8``-KF!`#"SS0`"['X`.@56N0@`
M,./0\E``!.,`\E@`!,+:CQN\W,(*CQN\W+D:`-GKE@`"``SLE@`A'E:YY(!I
MN8$`&;F``!ZY@0`6N0@`';GH@("Y"``W[',@OP!5[#,[OR55[#<`.@56N0@`
M,>L>``(`#.P>`"$>5NS1(+\`5;GDT`GL8R"_`%7LXSN_)56SP0!(N>80.;F`
M`#>Y@0`PL\T`!.SF`#H%5KD(`##C@/)@``3"BH\;O-RY!``(N1H`">N7``(`
M#.R7`"$>5KGDT'FY@0`9N8``%KF!`!>Y"``0N0@`/N.`\F@`!.SC(+\`5<**
MCQN\W.PS.[\E5>P^`#H%5KD(`#'K%@`"``SL%@`A'E;L82"_`%6YY&`)[',@
MOP!5N>C0V.R#.[\E5;/!`!VYYA`YN8``/KF!`#"SS0`![(<`.@56N0@`,./0
M\G``!+D(`#C"VH\;O-RY!``-N1H`">S3(+\`5>N>``(`#.R>`"$>5NSC.[\E
M5;GD8(FY@0`9[.T`.@56N8``%^,P\G@`!+F!`!C".H\;O-RY"``0N>A@`[D(
M`.'L;CN_)57L;B`Z!5;K%P`"``RSP0!6[!<`(1Y6XV#R@``$[($@OP!5N>80
M>;GD@#FY@`!]PFJ/&[S<N8$`<[D:`&FY"`!PL\$`=K/-`)7C8/*(``2YZ)"7
MPFK*8L'6[`D[OR55ZWT``@`,[`D@.@56['T`(1Y6N00`T+GD@#>YZ("&P.H`
M````N8$`%[/!`"BY@``>L\T`![F!`!/KC@`"``RY"``0[(X`(1Y6N0@`';/-
M`&*YYX#7XS#RD``$N8(`V<(ZRF+!UKD:`&VY&@`W[.$[OR55['DBOSY5[.$@
M.@56['D"(1Y6N0@`YK/!`&/L#CN_)56YYW`X[`X@.@56N8(`,>QA(K\^5>.0
M\I@`!.QA`B$>5L*:RF+!UKGG8->Y&@"8N8(`WK/!``FSS0"6N1H`D[D(`)"S
MS0``[!D[OR55N1H`#>P9(#H%5KD(`!#L,3N_)57L,2`Z!5:SP0`3L\T`T>.`
M\J``!.,P\J@`!,**RF+!UL(ZRF+!UKD:`(>Y&@`V['XBOSY5['X"(1Y6N>=P
MYNQI(K\^5;F"`.GL:0(A'E:Y&@".N>=@![D(`(VY@@`![)@[OR55N1H`,.R8
M(#H%5KD(`#GLTSN_)57LTR`Z!5;LD2*_/E7CX/*P``3LD0(A'E;"ZLIBP=:Y
MYY`&N1H`Y[F"``BY&@#@N0@`[>S>.[\E5>S>(#H%5N,0\K@`!+/!`'W"&LIB
MP=;CT/+```2Y&@`6PMK*8L'6[&@BOSY5N1H`V>QH`B$>5KGG8(FY@@"#[',B
MOSY5N1H`&.QS`B$>5K/-`)>YYW"&N0@`&;F"`([L`3N_)57C,/+(``3L`2`Z
M!5;".LIBP=:Y&@`VN00`;>S>(K\^5;D:`&BY"`!@[-X"(1Y6N>?0Y[F"`.'C
M@/+0``3LECN_)56Y&@`^[)8@.@56PHK*8L'6N0@`.;D:`(?L`SN_)57L<2*_
M/E7L`R`Z!5;L<0(A'E;C$/+8``2YYW#MPAK*8L'6N8(`YKD:`!WLUB*_/E7L
MU@(A'E:YY]!GN8(`8[D:`(ZY&@`6N0@`@.R3(K\^5>P(.[\E5>R3`B$>5NP(
M(#H%5KGGD&VY@@!HN0@`$./@\N``!.P!.[\E5<+JRF+!UNP!(#H%5KD:`.>Y
M&@#F[&@BOSY5N0@`X.QH`B$>5NR..[\E5;GG8'GLCB`Z!5:Y@@!QL\$`&.,P
M\N@`!..`\O``!,(ZRF+!UL**RF+!UKD:`#VY&@")N1H`-[/-`)'L<2*_/E6Y
M"``Y['$"(1Y6[`,[OR55N>=PUNP#(#H%5KF"`-[C$/+X``2Y&@"-PAK*8L'6
MN0@`@+D:`!;L;B*_/E7L;@(A'E;LZ#N_)56YYV`'[.@@.@56N8(``[D:`!"Y
M"``>[-$[OR55[-$@.@56[.,BOSY5XY#S```$[.,"(1Y6PIK*8L'6N>?@!KD:
M`)>Y@@`(N1H`D+D(`)WLV3N_)57LV2`Z!5;C,/,(``2SP0`MPCK*8L'6X]#S
M$``$N1H`-L+:RF+!UNQH(K\^5;D:`-[L:`(A'E:YYV".L\T`XKF"`(&Y&@`X
MN0@`/NP#.[\E5>P#(#H%5NR!(K\^5>SI(K\^5>R!`B$>5NSI`B$>5KGG@';C
M$/,8``2Y@@!YPAK*8L'6N1H`U[D:`!:YZ`!MN>?@".R6(+\`5;GG,'"Y!`#>
M[`8[OR55X]`@(``(N1H`%\#:`````.P)`#H%5N/0("``)+D(`!#LTR*_/E7K
M"0`"``SLTP(A'E;L"0`A'E:YZ+!]N8(`[<!Z`````.-P(!@`)+GG8+ZY"``%
MXS#S(``$P`H`````XP`@$``DPCK*8L'6XV#PH``$N0@`-.Q!(+\`5;D:`#BY
M"`!D[($[OR55P&H`````XV`@"``D[(0`.@56N00`$[D:`!NY"``8P!H`````
MXQ`@```DU0?S**`HIW0`"NMO\V``!`?^N00`3:?T]/G`Y?__X@H'!P<'!P?K
M[_!P`"2G*0"`X_#_8/]QP.7__^`LP#%G12,!P`_OS:N)XS`@```DXP`@"``D
MP$^8NMS^P%$0,E1VXT`@$``DXU`@&``DP#_#TN'PY4@@*```XS`@(``DY4@@
M,```Y4P@>```Z^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-N00`LN,@("@`!+D(
M`!+L42"_`%6Y!`"4X_#_8/]QXT"P,``$N00`H[DQ`"&GQ``$ITL``>-0L"@`
M).L)`!T`#+D(``3C`+`P`"3CT+!X`!*G=`")07"P.*>>`#^GQ`"M[&G_P`#8
MB&``!NSF``$`V.P>'[D&5>Q1_\``V4'1H`#KA0`&``RGBP`![$@^OP!5IX0`
M+*=/``&GA``:IT\``J>$``S2/W``H`"Y!``K0:"@0,#E___T#=(_<`"@`+D$
M`"M!H*!`P.7___0#TC]P`*``N00`*T&@H$#`Y?__\_FY(`"MIX0`*>N(``(`
M#-(_<`"@`+D$`"O`Y?__\^JY!``KTC]P`*!`P.7___/BN00`*](_<`"@@,#E
M___SVKD$`"O2/W``H,!!H*$`P.7___/0IX?_WJ>:_\")8``&&Y:Y%`"9N00`
M/;D$`">Y!`!)P.7__^(N4)"P>.MO\-``!`?^IX@`0!N-&8FY!``ZN?(PB4%P
ML#BY%`!HN00`)[D$`$:Y&``MP.7__^(3&#A:,+!X4#"P>*<^`$"G=/_@&YBY
M"`"FN10`F;D$`"O`Y?__\Y"G]/]3N00`VJ?T_\4'!P<'!P?K?_`X`"2Y!`"S
MXX`P*``$XY`P,``$[!@ZOSU503`P.+D4`$&Y!`"BIQH``4%4L#B2@%``N10`
M(;D(`#+C\/]@_W&G'@`XI\0`HZ?H`$"Y^1`N&>&GA`!A[!+__P#8N00`(^M!
M``@`WA)$IX0`4>QT__\`V!A4[`0^OP!5IX0`*:<.``&GA``9IPX``J>$``OC
M(#0``#;7_S``,``81T$@,0#C("0``#;7_R``(`"G2O__02`A`.,@)```-M?_
M(``@`*=.``%!("$`IX0`(>LU``(`WN,@)```-M?_(``@`.,@)0``-M?_(0`A
M`.,@)@``-M?_(@`B`.,@)P``-M?_(P`C`$$@)`"G-O_FN18`X<;@````IKD$
M`"O`Y?__\O?7-[`XL#BY!``KIWD``.QY``=@5>QY"`]@5>QY$!=@5>QY&!\@
M5>R'`!\`5>.`L'``),#E___RV[D$`"O2`J``L`32`*`#L`?2`Z`$L`S2`Z`(
ML!32`Z`,L!S2`Z`0L"3K?_#8``3`]/__X*&G"``XN?D0<!D!IX3_R.P7__\`
MV+D$`"/K<0`(`-X2=Z>$`%'LY___`-@85^P'/K\`5:>$`"FG#@`!IX0`&:<.
M``*GA``+XR`T```VU_\P`#``&'Y!(#$`XR`D```VU_\@`"``IWK__T$@(0#C
M("0``#;7_R``(`"G?@`!02`A`*>$`"'K-0`"`-[C("0``#;7_R``(`#C("4`
M`#;7_R$`(0#C("8``#;7_R(`(@#C("<``#;7_R,`(P!!("0`IS;_YKD6`$'&
M0`````BG]/]GUP`@`"``UP`@`"``Q%@``##TP/3__]WM!P<'!^MO\#``)+D$
M`!^G^_]@XQ#P```DP,```"_.!P?C0/$0``3K;_#0``0']`<'```````"``$E
M<R\E<P`O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4```O<')O8R\E:2\E<P!E>&4`+@!0
M05)?5$5-4```4$%27U!23T=.04U%```Z`"\`4$523#5,24(``%!%4DQ,24(`
M4$523#5/4%0``%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.```Q`&QS965K(&9A:6QE9```<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```)7,E<R5S)7,`
M`'!A<BT``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(``'-H;W)T(')E860`
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U
M)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-C,`56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"UE```M+0``55-%4@``55-%4DY!344``%1%35!$25(`5$U0`"]T
M;7```&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE
M+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN
M4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").
M(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<
M,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`
M7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I
M("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP
M;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F
M:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N
M9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("10
M05)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M
M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA
M;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@
M,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N
M=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M
M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S
M>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S
M971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@
M>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[
M("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M
M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F
M:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A
M="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*
M<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N
M92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@
M8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#
M86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D
M1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B
M=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F
M<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!
M1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%
M04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*
M)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE
M("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*
M;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M
M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O
M=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I
M;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI]
M(&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N
M86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S
M=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?
M9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@
M*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@
M>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@
M)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<[
M"B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*
M:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%
M3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF
M)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@
M/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,``$-!0TA%
M```````````!&P,[````[````!S__X#0```%U/__@U@```$(__^$4````3C_
M_X4P```!F/__A<````'(__^'*````@3__XG(```"1/__BK@```*`__^+,```
M`KS__XMH```"T/__C$````,,__^,2````R#__XZH```#7/__CN````.(__^0
M*````\S__Y8(```$`/__EH````0P__^6^```!%S__YCX```$E/__F2@```2T
M__^:&```!03__Z"P```%5/__HO@```60__^CT```!AC__[J(```&6/__NO@`
M``9\__^\R```!KS__[\P```&^``````````4``````%Z4@`!>`X!&PP/H`$'
M#@`````4````'/__@D@```!"```````````````4``````%Z4@`!>`X!&PP/
MH`$```````!<````'/__@Q````#<`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MP`("F`K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+RLG(Q\8.H`%""TX*S\[-S,O*
MR<C'Q@Z@`4(+```````L````?/__@Y````".`$:*"HL)C`B-!XX&CP5&#M@#
M`GH*S\[-S,O*#J`!0@L````X````K/__@_````%B`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.X`-T"L_.S<S+RLG(Q\8.H`%""P`````\````Z/__A1P```*<
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.V`(#`60*S\[-S,O*R<C'Q@Z@`4(+
M````````.````2C__X=\````\`!&APV(#(D+B@J+"8P(C0>.!H\%1@[((@*4
M"L_.S<S+RLG(QPZ@`4(+````````.````63__X@P````=`!>A@Z'#8@,B0N*
M"HL)C`B-!XX&CP5,#L@"`DC/SLW,R\K)R,?&#J`!````````$````:#__XAL
M````.``````````X```!M/__B)````#4`$:&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.V$("N`K/SLW,R\K)R,?&#J`!0@L````0```!\/__B2P````&````````
M`#@```($__^)(````EP`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[P(P)V"L_.
MS<S+RLG(Q\8.H`%""P```"@```)`__^+1````#8`2HL)C`B-!XX&CP5&#L`"
M8,_.S<S+#J`!````````0````FS__XM0```!2`!&B0N*"HL)C`B-!XX&CP5&
M#L@B`N0*S\[-S,O*R0Z@`4(+7`K/SLW,R\K)#J`!1@L````````P```"L/__
MC%0```7<`$:*"HL)C`B-!XX&CP5&#M`"`P6<"L_.S<S+R@Z@`48+````````
M+````N3__Y(`````>`!,BPF,"(T'C@:/!48.T`("5@K/SLW,RPZ@`4(+````
M````*````Q3__Y)(````>`!:A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"````
M```T```#0/__DI0```(``$Z(#(D+B@J+"8P(C0>.!H\%1@[0@@0#`<`*S\[-
MS,O*R<@.H`%""P```!P```-X__^47````"X`1HX&CP5&#L`"8,_.#J`!````
M3````YC__Y1L````Z@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N`"`E(*S\[-
MS,O*R<C'Q@Z@`48+`GH*S\[-S,O*R<C'Q@Z@`48+``````!,```#Z/__E0P`
M``:8`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.D`4#`GH*S\[-S,O*R<C'Q@Z@
M`4(+`P+."L_.S<S+RLG(Q\8.H`%&"P```#@```0X__^;5````D0`1H<-B`R)
M"XH*BPF,"(T'C@:/!5(.T`(#`;P*S\[-S,O*R<C'#J`!0@L``````$````1T
M__^=8````-8`1HD+B@J+"8P(C0>.!H\%1@[0`@)D"L_.S<S+RLD.H`%""P)8
M"L_.S<S+RLD.H`%&"P``````0```!+C__WKT```"B`!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5&#N@"`P'$"L_.S<S+RLG(Q\8.H`%""P`````````````\```$
M_/__G;```!:R`$Z&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#%HX*S\[-S,O*
MR<C'Q@Z@`4(+````````(```!3S__[0H````;`!*C@:/!48.P`("6L_.#J`!
M````````/```!6#__[1T```!R@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L`"
M`P%""L_.S<S+RLG(Q\8.H`%""P```````#@```6@__^V!````F@`1H<-B`R)
M"XH*BPF,"(T'C@:/!7P.P`(#`40*S\[-S,O*R<C'#J`!1@L``````!````7<
M__^X,`````P`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",X````````(O```````````0``
M``````+'``````````$````````"UP`````````,````````&,``````````
M#0```````%XP`````````!D```````"[T``````````;``````````@`````
M````&@```````+O8`````````!P`````````"`````!O__[U`````````I``
M````````!0````````P0``````````8````````#<``````````*````````
M!$<`````````"P`````````8`````````!4````````````````````#````
M````O>```````````@````````3X`````````!0`````````!P`````````7
M````````$\@`````````!P```````!%P``````````@````````"6```````
M```)`````````!@`````````'@`````````(`````&____L`````"````0``
M``!O___^````````$1``````;____P`````````!`````&____`````````0
M6`````!O___Y``````````X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````+O@`````````````````````````````!DN````````
M&4X````````9;@```````!F.````````&:X````````9S@```````!GN````
M````&@X````````:+@```````!I.````````&FX````````:C@```````!JN
M````````&LX````````:[@```````!L.````````&RX````````;3@``````
M`!MN````````&XX````````;K@```````!O.````````&^X````````<#@``
M`````!PN````````'$X````````<;@```````!R.````````'*X````````<
MS@```````!SN````````'0X````````=+@```````!U.````````'6X`````
M```=C@```````!VN````````'<X````````=[@```````!X.````````'BX`
M```````>3@```````!YN````````'HX````````>K@```````![.````````
M'NX````````?#@```````!\N````````'TX````````?;@```````!^.````
M````'ZX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````'\```````````````````,`("E!!4BYP;0H`````````````
M`````&%@````````7KP``````````````````%]<````````7V````````!A
M5````````%["````````85P``````````````````&%$````````84H`````
M`````````````&%F1T-#.B`H1&5B:6%N(#$S+C(N,"TQ.2D@,3,N,BXP```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````````````````````````````````````````````````"P````$`````
M`````@````````(X`````````C@`````````#P````````````````````$`
M`````````````!,````'``````````(````````"2`````````)(````````
M`"0````````````````````$```````````````F````!P`````````"````
M`````FP````````";``````````@````````````````````!```````````
M````-&____8``````````@````````*0`````````I``````````W`````4`
M``````````````@``````````````#X````+``````````(````````#<```
M``````-P````````"*`````&`````@`````````(`````````!@```!&````
M`P`````````"````````#!`````````,$`````````1'````````````````
M`````0``````````````3F____\``````````@```````!!8````````$%@`
M````````N`````4```````````````(``````````@```%MO___^````````
M``(````````1$````````!$0`````````&`````&`````0`````````(````
M``````````!J````!``````````"````````$7`````````1<`````````)8
M````!0``````````````"``````````8````=`````0`````````0@``````
M`!/(````````$\@````````$^`````4````5``````````@`````````&```
M`'X````!``````````8````````8P````````!C``````````$``````````
M```````````$``````````````!Y`````0`````````&````````&0``````
M```9``````````;`````````````````````!``````````@````A`````$`
M````````!@```````!_`````````'\`````````^<```````````````````
M``@``````````````(H````!``````````8```````!>,````````%XP````
M`````"P````````````````````$``````````````"0`````0`````````"
M````````7F````````!>8````````$"0````````````````````"```````
M````````F`````$``````````@```````)[P````````GO``````````[```
M``````````````````0``````````````*8````!``````````(```````"?
MX````````)_@````````!B`````````````````````(``````````````"P
M````#@`````````#````````N]````````"KT``````````(````````````
M````````"``````````(````O`````\``````````P```````+O8````````
MJ]@`````````"`````````````````````@`````````"````,@````&````
M``````,```````"[X````````*O@`````````@`````&```````````````(
M`````````!````#1`````0`````````#````````O>````````"MX```````
M``(@````````````````````"``````````(````U@````$``````````P``
M`````,``````````L```````````B`````````````````````@`````````
M`````-P````(``````````,```````#`B````````+"(`````````"@`````
M```````````````(``````````````#A`````0`````````P````````````
M``````"PB``````````?`````````````````````0`````````!`````0``
M``,`````````````````````````````L*<`````````Z@``````````````
-``````$`````````````
